package ch.fabric.datadroppers;

public class FabricDatadroppersDemo {

	public static void main(String[] args) {
		// Create a new datadroppers access tool...
		Datadroppers _myDatadroppers = new Datadroppers();

		System.out.println("[Datadroppers Processing Demo] - Getting info for data 'sensor_1'...");

		// Pick info of a data named "sensor_1"...
		DataSignature aSignature = _myDatadroppers.pickDataInfo("sensor_1");

		System.out.println("Data unique id is "+aSignature.getId()+"\nData label is "+aSignature.getLabel()+"\nData unit is "+aSignature.getUnit());
		
		int aRandomValue = (int)(Math.random()*1000);
		System.out.println("[Datadroppers Processing Demo] - Drop the new value ("+aRandomValue+") for data 'sensor_1'...");

		// Drop the new value to the data "sensor_1"
		boolean dropResult = _myDatadroppers.drop("sensor_1", String.valueOf(aRandomValue));
		if (!dropResult) {
			System.out.println("Error while adding a new value to 'sensor_1', error num ("+_myDatadroppers.getReturned()+")");
		}
		
		// Pick the last value for the data named "sensor_1"
		DataValue aValue = _myDatadroppers.pick("sensor_1");
		System.out.println("[Datadroppers Processing Demo] - The value '"+aValue.getValue()+"' was added at '"+aValue.getTimestamp()+"' for the data named 'sensor_1'");
		
		// Search for all deterritorialized project's data...
		DataSignature [] allDeterritorializedData = _myDatadroppers.searchData("deterritorialized");
		
		System.out.println("\n\n("+allDeterritorializedData.length+") data for 'deterritorialized' (www.deterritorialized.org) was found in datadroppers");
		System.out.println("[Datadroppers Processing Demo] - Collecting information for all deterritorialized data...");
		DataSignature currentInfo;
		for(int i=0;i<allDeterritorializedData.length;i++) {
			currentInfo = _myDatadroppers.pickDataInfo(allDeterritorializedData[i].getId());
			if (currentInfo == null)
				System.out.println("("+_myDatadroppers.getReturned()+")");

			System.out.println("Deterritorialized data number ("+i+") -- label is ("+currentInfo.getLabel()+"), unit is ("+currentInfo.getUnit()+").");
		}
		
	    // ----- EXAMPLE - Add a new datadroppers feed
	    // Generate a dummy unique name for the new datadroppers feed
	    String baseName = "dummyFeed";
	    aRandomValue = (int)(Math.random()*10000);
	    
	    // Check if the feed already exists in datadroppers
	    DataSignature [] searchResult = _myDatadroppers.searchData(baseName+aRandomValue);
	    while(searchResult.length > 0) {
	      aRandomValue = (int)(Math.random()*10000);
	      searchResult = _myDatadroppers.searchData(baseName+aRandomValue);
	    }
	    
	    System.out.println("[Datadroppers Processing Demo] - new datadroppers feed will be ("+baseName+aRandomValue+")");
	    
	    // Create the new feed...
	    boolean creationResult = _myDatadroppers.createData(baseName+aRandomValue, "dummy test feed nothing relevant here", "integer", "degrees", "unset");
	    if (!creationResult) {
	      // An error may occure, let's see what datadroppers lib says about it...
	    	System.out.println("[Datadroppers Processing Demo] - Error while creating a new feed ("+_myDatadroppers.getReturned()+")");
	    } else {
		    // Drop a new value to the data the newly created feed...
		    dropResult = _myDatadroppers.drop(baseName+aRandomValue, "666");
		    if (!dropResult) {
		    	System.out.println("[Datadroppers Processing Demo] - Error while dropping a new value to feed '"+baseName+aRandomValue+"', error num ("+_myDatadroppers.getReturned()+")");
		    }
	
		    // Pick the last value for the data named 'sensor_1'
		    DataValue aNewValue = _myDatadroppers.pick(baseName+aRandomValue);
		    if (aNewValue != null)
		    	System.out.println("[Datadroppers Processing Demo] - The value '"+aNewValue.getValue()+"' was added at '"+aNewValue.getTimestamp()+"' for the data named '"+baseName+aRandomValue+"'");
	    }
	    // -----
	}
}
