// Get access to the datadroppers library
import ch.fabric.datadroppers.*;

// My main access to the Owncloud server
Datadroppers _myDatadroppers;

void setup() {
    // Nothing to draw in this example, just few calls to the fabric.ch's datadroppers library, so no loop!
    noLoop();
}

void draw() {
    // ----- Create a new datadroppers object
    _myDatadroppers = new Datadroppers(this);

    // ----- EXAMPLE - Getting information about a datadroppers feed named 'sensor 1'
    // 'sensor 1' is a datadroppers demo feed.
    println("[Datadroppers Processing Demo] - Getting info for data feed named 'sensor 1'...");

    // Pick info of a data feed named "sensor 1"...
    DataSignature aSignature = _myDatadroppers.pickDataInfo("sensor 1");

    println("[Datadroppers Processing Demo] - Data for 'sensor 1'\n[Datadroppers Processing Demo] - unique id is "+aSignature.getId()+"\n[Datadroppers Processing Demo] - Data label is "+aSignature.getLabel()+"\n[Datadroppers Processing Demo] - Data unit is "+aSignature.getUnit());
    // -----
    
    // ----- EXAMPLE - Drop (add/push) a value to datadroppers feed named 'sensor 1'
    // 'sensor 1' is a demo datadroppers feed. Avoid to drop value in a
    // datadroppers feed if it is not your own feed or if you were not invited to do
    // so by the creator of the feed
    
    // Generate a random integer number...
    int aRandomValue = (int)(Math.random()*1000);
    
    println("[Datadroppers Processing Demo] - A new value ("+aRandomValue+") will be dropped to feed 'sensor 1'...");

    // Drop the new value to the data "sensor 1"
    boolean dropResult = _myDatadroppers.drop("sensor 1", String.valueOf(aRandomValue));
    if (!dropResult) {
      println("[Datadroppers Processing Demo] - Error while dropping a new value to feed 'sensor 1', error num ("+_myDatadroppers.getReturned()+")");
    }
    // -----
    
    // ----- EXAMPLE - Check the new last value for the datadroppers feed 'sensor 1'
    // Pick the last value for the data named 'sensor 1'
    DataValue aValue = _myDatadroppers.pick("sensor 1");
    println("[Datadroppers Processing Demo] - The value '"+aValue.getValue()+"' was added at '"+aValue.getTimestamp()+"' for the data feed named 'sensor 1'");
    // -----

    // ----- EXAMPLE - Add a new datadroppers feed
    // Generate a dummy unique name for the new datadroppers feed
    String baseName = "dummyFeed";
    aRandomValue = (int)(Math.random()*10000);
    
    // Check if the feed already exists in datadroppers
    DataSignature [] searchResult = _myDatadroppers.searchData(baseName+aRandomValue);
    while(searchResult.length > 0) {
      aRandomValue = (int)(Math.random()*10000);
      searchResult = _myDatadroppers.searchData(baseName+aRandomValue);
    }
    
    println("[Datadroppers Processing Demo] - new datadroppers feed will be ("+baseName+aRandomValue+")");
    
    // Create the new feed...
    boolean creationResult = _myDatadroppers.createData(baseName+aRandomValue, "dummy test feed nothing relevant here", "integer", "degrees", "unset");
    if (!creationResult) {
      // An error may occure, let's see what datadroppers lib says about it...
      println("[Datadroppers Processing Demo] - Error while creating a new feed ("+_myDatadroppers.getReturned()+")");
    }
    
    // Drop a new value to the data the newly created feed...
    dropResult = _myDatadroppers.drop(baseName+aRandomValue, "100");
    if (!dropResult) {
      println("[Datadroppers Processing Demo] - Error while dropping a new value to feed '"+baseName+aRandomValue+"', error num ("+_myDatadroppers.getReturned()+")");
    }

    // Pick the last value for the data named 'sensor 1'
    DataValue aNewValue = _myDatadroppers.pick(baseName+aRandomValue);
    println("[Datadroppers Processing Demo] - The value '"+aNewValue.getValue()+"' was added at '"+aNewValue.getTimestamp()+"' for the data feed named '"+baseName+aRandomValue+"'");
  
    // -----
    
    println("Done.");
    
    exit();
}

